@@ -171,6 +171,7 @@ __all__ = (
     "DescribeVpcEndpointsPaginatorName",
     "DescribeVpcPeeringConnectionsPaginatorName",
     "DescribeVpcsPaginatorName",
+    "DestinationFileFormatType",
     "DeviceTypeType",
     "DiskImageFormatType",
     "DiskTypeType",
@@ -243,6 +244,7 @@ __all__ = (
     "InstanceStateNameType",
     "InstanceStatusOkWaiterName",
     "InstanceStoppedWaiterName",
+    "InstanceStorageEncryptionSupportType",
     "InstanceTerminatedWaiterName",
     "InstanceTypeHypervisorType",
     "InstanceTypeType",
@@ -414,7 +416,7 @@ AllocationStrategyType = Literal[
 AllowsMultipleInstanceTypesType = Literal["off", "on"]
 AnalysisStatusType = Literal["failed", "running", "succeeded"]
 ApplianceModeSupportValueType = Literal["disable", "enable"]
-ArchitectureTypeType = Literal["arm64", "i386", "x86_64"]
+ArchitectureTypeType = Literal["arm64", "i386", "x86_64", "x86_64_mac"]
 ArchitectureValuesType = Literal["arm64", "i386", "x86_64", "x86_64_mac"]
 AssociatedNetworkTypeType = Literal["vpc"]
 AssociationStatusCodeType = Literal[
@@ -642,6 +644,7 @@ DescribeVpcEndpointServicesPaginatorName = Literal["describe_vpc_endpoint_servic
 DescribeVpcEndpointsPaginatorName = Literal["describe_vpc_endpoints"]
 DescribeVpcPeeringConnectionsPaginatorName = Literal["describe_vpc_peering_connections"]
 DescribeVpcsPaginatorName = Literal["describe_vpcs"]
+DestinationFileFormatType = Literal["parquet", "plain-text"]
 DeviceTypeType = Literal["ebs", "instance-store"]
 DiskImageFormatType = Literal["RAW", "VHD", "VMDK"]
 DiskTypeType = Literal["hdd", "ssd"]
@@ -769,6 +772,7 @@ InstanceStateNameType = Literal[
 ]
 InstanceStatusOkWaiterName = Literal["instance_status_ok"]
 InstanceStoppedWaiterName = Literal["instance_stopped"]
+InstanceStorageEncryptionSupportType = Literal["required", "unsupported"]
 InstanceTerminatedWaiterName = Literal["instance_terminated"]
 InstanceTypeHypervisorType = Literal["nitro", "xen"]
 InstanceTypeType = Literal[
@@ -1621,6 +1625,7 @@ ServiceName = Literal[
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
